@@ -486,6 +486,7 @@ update_account_object (GoaDaemon           *self,
   GoaAccount *account;
   GoaProvider *provider;
   gboolean is_locked;
+  gboolean is_temporary;
   gboolean ret;
   gchar *identity;
   gchar *presentation_identity;
@@ -516,6 +517,7 @@ update_account_object (GoaDaemon           *self,
   identity = g_key_file_get_string (key_file, group, "Identity", NULL);
   presentation_identity = g_key_file_get_string (key_file, group, "PresentationIdentity", NULL);
   is_locked = g_key_file_get_boolean (key_file, group, "IsLocked", NULL);
+  is_temporary = g_key_file_get_boolean (key_file, group, "IsTemporary", NULL);
   if (just_added)
     {
       account = goa_account_skeleton_new ();
@@ -538,6 +540,7 @@ update_account_object (GoaDaemon           *self,
   goa_account_set_identity (account, identity);
   goa_account_set_presentation_identity (account, presentation_identity);
   goa_account_set_is_locked (account, is_locked);
+  goa_account_set_is_temporary (account, is_temporary);
 
   error = NULL;
   if (!goa_provider_build_object (provider, object, key_file, group, self->connection, just_added, &error))
@@ -907,23 +910,8 @@ get_all_providers_cb (GObject      *source,
       g_key_file_set_string (key_file, group, key, value);
     }
 
-  g_free (key_file_data);
   error = NULL;
-  key_file_data = g_key_file_to_data (key_file,
-                                      &length,
-                                      &error);
-  if (key_file_data == NULL)
-    {
-      g_prefix_error (&error, "Error generating key-value-file: ");
-      g_dbus_method_invocation_take_error (data->invocation, error);
-      goto out;
-    }
-
-  error = NULL;
-  if (!g_file_set_contents (path,
-                            key_file_data,
-                            length,
-                            &error))
+  if (!g_key_file_save_to_file (key_file, path, &error))
     {
       g_prefix_error (&error, "Error writing key-value-file %s: ", path);
       g_dbus_method_invocation_take_error (data->invocation, error);
@@ -951,9 +939,7 @@ get_all_providers_cb (GObject      *source,
   g_free (group);
   g_free (id);
   g_free (path);
-  if (key_file != NULL)
-    g_key_file_free (key_file);
-
+  g_clear_pointer (&key_file, (GDestroyNotify) g_key_file_free);
   g_object_unref (data->daemon);
   g_object_unref (data->manager);
   g_object_unref (data->invocation);
@@ -1006,8 +992,6 @@ on_account_handle_remove (GoaAccount            *account,
   const gchar *provider_type;
   gchar *path;
   gchar *group;
-  gchar *data;
-  gsize length;
   GError *error;
 
   provider = NULL;
@@ -1015,7 +999,6 @@ on_account_handle_remove (GoaAccount            *account,
   path = NULL;
   group = NULL;
   key_file = NULL;
-  data = NULL;
 
   if (goa_account_get_is_locked (account))
     {
@@ -1055,21 +1038,7 @@ on_account_handle_remove (GoaAccount            *account,
     }
 
   error = NULL;
-  data = g_key_file_to_data (key_file,
-                             &length,
-                             &error);
-  if (data == NULL)
-    {
-      g_prefix_error (&error, "Error generating key-value-file: ");
-      g_dbus_method_invocation_take_error (invocation, error);
-      goto out;
-    }
-
-  error = NULL;
-  if (!g_file_set_contents (path,
-                            data,
-                            length,
-                            &error))
+  if (!g_key_file_save_to_file (key_file, path, &error))
     {
       g_prefix_error (&error, "Error writing key-value-file %s: ", path);
       g_dbus_method_invocation_take_error (invocation, error);
@@ -1114,9 +1083,7 @@ on_account_handle_remove (GoaAccount            *account,
 
  out:
   g_clear_object (&provider);
-  g_free (data);
-  if (key_file != NULL)
-    g_key_file_free (key_file);
+  g_clear_pointer (&key_file, (GDestroyNotify) g_key_file_free);
   g_free (group);
   g_free (path);
   return TRUE; /* invocation was handled */
