@@ -754,8 +754,7 @@ add_account (GoaProvider    *provider,
     g_assert (ret != NULL);
 
   g_free (data.account_object_path);
-  if (data.loop != NULL)
-    g_main_loop_unref (data.loop);
+  g_clear_pointer (&data.loop, (GDestroyNotify) g_main_loop_unref);
   g_clear_object (&data.cancellable);
   if (ews_client != NULL)
     g_object_unref (ews_client);
@@ -909,8 +908,7 @@ refresh_account (GoaProvider    *provider,
     g_propagate_error (error, data.error);
 
   gtk_widget_destroy (dialog);
-  if (data.loop != NULL)
-    g_main_loop_unref (data.loop);
+  g_clear_pointer (&data.loop, (GDestroyNotify) g_main_loop_unref);
   g_clear_object (&data.cancellable);
   if (ews_client != NULL)
     g_object_unref (ews_client);
