@@ -243,6 +243,8 @@ sign_in_identity (GoaKerberosProvider  *self,
                                        sign_in_thread,
                                        G_PRIORITY_DEFAULT,
                                        cancellable);
+
+  g_object_unref (operation_result);
 }
 
 static void
@@ -267,7 +269,7 @@ get_ticket_sync (GoaKerberosProvider *self,
                  GCancellable        *cancellable,
                  GError             **error)
 {
-  GVariant            *credentials;
+  GVariant            *credentials = NULL;
   GError              *lookup_error;
   GError              *sign_in_error;
   GoaAccount          *account;
@@ -281,7 +283,7 @@ get_ticket_sync (GoaKerberosProvider *self,
 
   ret = FALSE;
 
-  account = goa_object_peek_account (object);
+  account = goa_object_get_account (object);
   identifier = goa_account_get_identity (account);
 
   ticketing = goa_object_get_ticketing (object);
@@ -291,7 +293,7 @@ get_ticket_sync (GoaKerberosProvider *self,
                    GOA_ERROR,
                    GOA_ERROR_NOT_SUPPORTED,
                    _("Ticketing is disabled for account"));
-      return FALSE;
+      goto out;
     }
 
   details = goa_ticketing_get_details (ticketing);
@@ -350,12 +352,10 @@ get_ticket_sync (GoaKerberosProvider *self,
 
   ret = TRUE;
 out:
+  g_clear_object (&account);
   g_clear_object (&ticketing);
   g_free (object_path);
-
-  if (credentials != NULL)
-    g_variant_unref (credentials);
-
+  g_clear_pointer (&credentials, (GDestroyNotify) g_variant_unref);
   return ret;
 }
 
@@ -843,7 +843,7 @@ on_initial_sign_in_done (GoaKerberosProvider *self,
   else if (remember_password)
     {
       GVariantBuilder  builder;
-      const char      *object_path;
+      char            *object_path;
 
       object_path = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (result));
 
@@ -871,6 +871,8 @@ on_initial_sign_in_done (GoaKerberosProvider *self,
                                                        NULL,
                                                        NULL);
         }
+
+      g_free (object_path);
     }
 
   g_simple_async_result_complete_in_idle (operation_result);
@@ -1317,8 +1319,7 @@ start_over:
   g_free (request.account_object_path);
   g_free (principal);
   g_free (principal_for_display);
-  if (request.loop != NULL)
-    g_main_loop_unref (request.loop);
+  g_clear_pointer (&request.loop, (GDestroyNotify) g_main_loop_unref);
   return object;
 }
 
@@ -1365,14 +1366,14 @@ ensure_credentials_sync (GoaProvider    *provider,
                          GError        **error)
 {
   GoaIdentityServiceIdentity *identity = NULL;
-  GoaAccount                 *account;
+  GoaAccount                 *account = NULL;
   const char                 *identifier;
   gint64                      timestamp;
   GDateTime                  *now, *expiration_time;
   GTimeSpan                   time_span;
   gboolean                    credentials_ensured = FALSE;
 
-  account = goa_object_peek_account (object);
+  account = goa_object_get_account (object);
   identifier = goa_account_get_identity (account);
 
   ensure_identity_manager ();
@@ -1434,13 +1435,16 @@ ensure_credentials_sync (GoaProvider    *provider,
   if (time_span < 0 || time_span > G_MAXINT)
     time_span = 0;
 
-  *out_expires_in = (int) time_span;
+  if (out_expires_in != NULL)
+    *out_expires_in = (int) time_span;
+
   credentials_ensured = TRUE;
 
   g_date_time_unref (now);
   g_date_time_unref (expiration_time);
 
 out:
+  g_clear_object (&account);
   g_clear_object (&identity);
   g_mutex_unlock (&identity_manager_mutex);
   return credentials_ensured;
