@@ -225,14 +225,14 @@ lastfm_login_sync (GoaProvider                  *provider,
   json_obj = json_node_get_object (root);
   session_obj = json_node_get_object (json_object_get_member (json_obj, "session"));
 
-  if (g_strdup (json_object_get_string_member (session_obj, "name")) == NULL)
+  if (json_object_get_string_member (session_obj, "name") == NULL)
     {
       g_set_error (error, GOA_ERROR, GOA_ERROR_FAILED, _("Could not parse response"));
       goto out;
     }
 
 
-  if (g_strdup (json_object_get_string_member (session_obj, "key")) == NULL)
+  if (json_object_get_string_member (session_obj, "key") == NULL)
     {
       g_set_error (error, GOA_ERROR, GOA_ERROR_FAILED, _("Could not parse response"));
       goto out;
@@ -545,7 +545,7 @@ check_cb (RestProxyCall *call,
     }
   session_obj = json_node_get_object (session);
 
-  if (g_strdup (json_object_get_string_member (session_obj, "name")) == NULL)
+  if (json_object_get_string_member (session_obj, "name") == NULL)
     {
       g_set_error (&data->error, GOA_ERROR, GOA_ERROR_FAILED, _("Could not parse response"));
       goto out;
@@ -620,6 +620,10 @@ lastfm_login (GoaProvider                  *provider,
   rest_proxy_call_async (call, callback, NULL, data, &data->error);
 
   g_signal_connect (cancellable, "cancelled", G_CALLBACK (on_rest_proxy_call_cancelled_cb), call);
+
+  g_free (sig_md5);
+  g_free (sig);
+  g_object_unref (call);
 }
 
 /* ---------------------------------------------------------------------------------------------------- */
@@ -754,9 +758,9 @@ add_account (GoaProvider    *provider,
   else
     g_assert (ret != NULL);
 
+  g_free (data.access_token);
   g_free (data.account_object_path);
-  if (data.loop != NULL)
-    g_main_loop_unref (data.loop);
+  g_clear_pointer (&data.loop, (GDestroyNotify) g_main_loop_unref);
   g_clear_object (&data.cancellable);
   return ret;
 }
@@ -886,8 +890,8 @@ refresh_account (GoaProvider    *provider,
     g_propagate_error (error, data.error);
 
   gtk_widget_destroy (dialog);
-  if (data.loop != NULL)
-    g_main_loop_unref (data.loop);
+  g_clear_pointer (&data.loop, (GDestroyNotify) g_main_loop_unref);
+  g_free (data.access_token);
   g_clear_object (&data.cancellable);
   return ret;
 }
