@@ -47,9 +47,6 @@ struct _GoaIdentityServicePrivate
   GHashTable               *key_holders;
   GHashTable               *pending_temporary_account_results;
 
-  /* FIXME: This is a little ucky, since the goa service
-   * is in process, we should able to use direct calls.
-   */
   GoaClient                *client;
   GoaManager               *accounts_manager;
 };
@@ -307,6 +304,8 @@ on_sign_in_handled (GoaIdentityService    *self,
                                                      invocation,
                                                      object_path);
     }
+
+  g_object_unref (invocation);
 }
 
 static void
@@ -445,7 +444,7 @@ on_identity_signed_out (GoaIdentityManager *manager,
   GError             *error;
   GoaIdentity        *identity;
   const char         *identifier;
-  GoaObject          *object;
+  GoaObject          *object = NULL;
 
   error = NULL;
   goa_identity_manager_sign_identity_out_finish (manager, result, &error);
@@ -467,6 +466,8 @@ on_identity_signed_out (GoaIdentityManager *manager,
     ensure_account_credentials (self, object);
 
   g_simple_async_result_complete_in_idle (operation_result);
+
+  g_clear_object (&object);
   g_object_unref (operation_result);
 }
 
@@ -750,20 +751,20 @@ on_identity_needs_renewal (GoaIdentityManager *identity_manager,
                            GoaIdentityService *self)
 {
   const char *principal;
-  GoaObject  *object;
+  GoaObject  *object = NULL;
 
   principal = goa_identity_get_identifier (identity);
 
-  g_debug ("GoaIdentityService: identity %s needs renewal", principal);
-
   object = find_object_with_principal (self, principal, TRUE);
 
-  if (object != NULL)
+  if (object != NULL && should_ignore_object (self, object))
     {
-      should_ignore_object (self, object);
-      return;
+      g_debug ("GoaIdentityService: ignoring identity %s that says it needs renewal", principal);
+      goto out;
     }
 
+  g_debug ("GoaIdentityService: identity %s needs renewal", principal);
+
   goa_identity_manager_renew_identity (GOA_IDENTITY_MANAGER
                                        (self->priv->identity_manager),
                                        identity,
@@ -771,6 +772,9 @@ on_identity_needs_renewal (GoaIdentityManager *identity_manager,
                                        (GAsyncReadyCallback)
                                        on_identity_renewed,
                                        self);
+
+ out:
+  g_clear_object (&object);
 }
 
 static void
@@ -891,7 +895,6 @@ add_temporary_account (GoaIdentityService *self,
   char               *realm;
   char               *preauth_source;
   const char         *principal;
-  char               *principal_for_display;
   GSimpleAsyncResult *operation_result;
   GVariantBuilder     credentials;
   GVariantBuilder     details;
@@ -912,8 +915,6 @@ add_temporary_account (GoaIdentityService *self,
 
   /* If there's no account for this identity then create a temporary one.
    */
-  principal_for_display = goa_identity_manager_name_identity (self->priv->identity_manager,
-                                                              identity);
 
   realm = goa_kerberos_identity_get_realm_name (GOA_KERBEROS_IDENTITY (identity));
   preauth_source = goa_kerberos_identity_get_preauthentication_source (GOA_KERBEROS_IDENTITY (identity));
@@ -942,7 +943,7 @@ add_temporary_account (GoaIdentityService *self,
   goa_manager_call_add_account (self->priv->accounts_manager,
                                 "kerberos",
                                 principal,
-                                principal_for_display,
+                                principal,
                                 g_variant_builder_end (&credentials),
                                 g_variant_builder_end (&details),
                                 NULL,
@@ -951,7 +952,6 @@ add_temporary_account (GoaIdentityService *self,
                                 operation_result);
   g_free (realm);
   g_free (preauth_source);
-  g_free (principal_for_display);
 }
 
 static void
@@ -970,6 +970,8 @@ on_identity_added (GoaIdentityManager *identity_manager,
 
   if (object == NULL)
     add_temporary_account (self, identity);
+
+  g_clear_object (&object);
 }
 
 static void
@@ -987,6 +989,7 @@ on_identity_removed (GoaIdentityManager *identity_manager,
     ensure_account_credentials (self, object);
 
   unexport_identity (self, identity);
+  g_clear_object (&object);
 }
 
 static void
@@ -1004,6 +1007,8 @@ on_identity_refreshed (GoaIdentityManager *identity_manager,
     add_temporary_account (self, identity);
   else
     ensure_account_credentials (self, object);
+
+  g_clear_object (&object);
 }
 
 typedef struct
@@ -1344,6 +1349,7 @@ on_identity_expiring (GoaIdentityManager *identity_manager,
     return;
 
   ensure_account_credentials (self, object);
+  g_clear_object (&object);
 }
 
 static void
@@ -1364,6 +1370,7 @@ on_identity_expired (GoaIdentityManager *identity_manager,
     return;
 
   ensure_account_credentials (self, object);
+  g_clear_object (&object);
 }
 
 static void
